@@ -5,7 +5,7 @@ UNIT_TEMP_CELSIUS = "°C"
 UNIT_TEMP_FAHRENHEIT = "°F"
 UNIT_PERCENTAGE = "%"
 UNIT_OZ = "oz"
-UNIT_ML = "ml"
+UNIT_LITRE = "l"
 UNIT_BUBBLES_PER_MINUTE = "bpm"
 
 METRIC = "1"
